@@ -1,11 +1,14 @@
-from onlineafspraken.api.client import OnlineAfsprakenAPI, client
+from typing import List
+
+from onlineafspraken.api.client import client
 from onlineafspraken.schema.appointment import (
     CancelAppointmentResponse,
     ConfirmAppointmentResponse,
     GetAppointmentsResponse,
     GetAppointmentResponse,
     SetAppointmentResponse,
-    SetAppointmentSchema, AppointmentSchema,
+    SetAppointmentSchema,
+    AppointmentSchema,
 )
 
 
@@ -15,11 +18,11 @@ def cancel_appointment(
 
     resp = client.get(
         "cancelAppointment",
-        id=appointment_id,
-        mode=mode,
-        remarks=remarks,
-        confirmation=confirmation,
-        dryRun=dry_run,
+        Id=appointment_id,
+        Mode=mode,
+        Remarks=remarks,
+        Confirmation=confirmation,
+        DryRun=dry_run,
     )
 
     return CancelAppointmentResponse.parse_obj(resp)
@@ -30,7 +33,7 @@ def confirm_appointment(
 ) -> ConfirmAppointmentResponse:
 
     resp = client.get(
-        "confirmAppointment", id=appointment_id, confirmationCode=confirmation_code
+        "confirmAppointment", Id=appointment_id, ConfirmationCode=confirmation_code
     )
 
     return ConfirmAppointmentResponse.parse_obj(resp)
@@ -38,42 +41,42 @@ def confirm_appointment(
 
 def get_appointments(
     agenda_id,
-    start_date,
-    end_date,
+    start_date=None,
+    end_date=None,
     customer_id=None,
     appointment_type_id=None,
     resource_id=None,
     include_cancelled=None,
     limit=None,
     offset=None,
-) -> GetAppointmentsResponse:
+) -> List[AppointmentSchema]:
 
     resp = client.get(
         "getAppointments",
-        agendaId=agenda_id,
-        startDate=start_date,
-        endDate=end_date,
-        customerId=customer_id,
-        appointmentTypeId=appointment_type_id,
-        resourceId=resource_id,
-        includeCancelled=include_cancelled,
-        limit=limit,
-        offset=offset,
+        AgendaId=agenda_id,
+        StartDate=start_date,
+        EndDate=end_date,
+        CustomerId=customer_id,
+        AppointmentTypeId=appointment_type_id,
+        ResourceId=resource_id,
+        IncludeCancelled=include_cancelled,
+        Limit=limit,
+        Offset=offset,
     )
 
-    return GetAppointmentsResponse.parse_obj(resp)
+    return GetAppointmentsResponse.parse_obj(resp["Objects"]).appointment
 
 
 def get_appointment(appointment_id) -> AppointmentSchema:
 
-    resp = client.get("getAppointment", id=appointment_id)
+    resp = client.get("getAppointment", Id=appointment_id)
 
     return GetAppointmentResponse.parse_obj(resp).appointment
 
 
 def remove_appointment(appointment_id) -> None:
 
-    response = client.get("removeAppointment", id=appointment_id)
+    response = client.get("removeAppointment", Id=appointment_id)
 
     return response
 
@@ -89,6 +92,7 @@ def set_appointment(
     name=None,
     description=None,
     booking_mode=None,
+    **custom_fields
 ) -> SetAppointmentSchema:
 
     resp = client.get(
@@ -103,6 +107,7 @@ def set_appointment(
         Name=name,
         Description=description,
         BookingMode=booking_mode,
+        **custom_fields,
     )
 
     response = SetAppointmentResponse.parse_obj(resp)
